@@ -59,7 +59,6 @@ static gint m_GokKeyboardX;
 static gint m_GokKeyboardY;
 static gboolean m_bKeysizePriority;
 static gboolean m_bWordCompleteOn;
-static gboolean m_bCommandPredictOn;
 static gint m_NumberPredictions;
 static gchar *m_NameAccessMethod = NULL;
 static gboolean m_bUseGtkPlusTheme;
@@ -104,7 +103,6 @@ void gok_data_initialize ()
 	m_bKeysizePriority = TRUE;
 	gok_data_set_name_accessmethod_internal ("directselection");
 	m_bWordCompleteOn = FALSE;
-	m_bCommandPredictOn = FALSE;
 	m_NumberPredictions = 5;
 	m_bUseGtkPlusTheme = FALSE;
 	m_bExpandWindow = TRUE;
@@ -966,33 +964,6 @@ void gok_data_set_wordcomplete (gboolean bTrueFalse)
 	m_bSettingsChanged = TRUE;
 }
 
-/**
- * gok_data_get_wordcomplete:
- *
- * Returns: TRUE if word completion is turned on, FALSE if it's turned off.
- */
-gboolean gok_data_get_commandprediction ()
-{
-	/* don't use during login mode */
-	if (gok_main_get_login()) {
-		return FALSE;
-	}
-	return TRUE;/* TODO m_bCommandPredictOn;*/
-}
-
-/**
- * gok_data_set_wordcomplete:
- * @bTrueFalse: The flag setting the word completion state.
- */
-void gok_data_set_commandprediction (gboolean bTrueFalse)
-{
-	m_bCommandPredictOn = bTrueFalse;
-/*	gok_gconf_set_bool (gconf_client, GOK_GCONF_WORD_COMPLETE,
-				 m_bWordCompleteOn);
-	m_bSettingsChanged = TRUE;
-	*/
-}
-
 /**
  * gok_data_get_num_predictions:
  *
