@@ -1,8 +1,9 @@
 /*
 * gok-editor.c
 *
-* Copyright 2001,2002 Sun Microsystems, Inc.,
-* Copyright 2001,2002 University Of Toronto
+* Copyright 2001-2009 Sun Microsystems, Inc.,
+* Copyright 2001-2009 University Of Toronto
+* Copyright 2009 Gerd Kohlberger <gerdko gmail com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
@@ -24,13 +25,13 @@
 #include <config.h>
 #endif
 
-#include <gnome.h>
-#include <glade/glade.h>
+#include <glib.h>
+#include <glib/gi18n.h>
 #include "gok-log.h"
 #include "gok-keyboard.h"
 #include "gok-editor.h"
 #include "gok-modifier.h"
-#include "gok-glade-helpers.h"
+#include "gok-ui-helper.h"
 
 #define TITLE_GOK_EDITOR _("GOK Keyboard Editor")
 
@@ -40,9 +41,9 @@ static GtkWindowGroup* m_pWindowGroup;
 /* pointer to the window that displays the key parameters */
 static GtkWidget* m_pWindowEditor = NULL;
 
-/* pointer to the glade xml structure for the window that 
+/* pointer to the ui xml structure for the window that
  * displays the key parameters */
-static GladeXML* m_pEditorXML = NULL;
+static GtkBuilder *builder = NULL;
 
 /* pointer to the window that displays the keyboard */
 static GtkWidget* m_pWindowKeyboard;
@@ -80,35 +81,27 @@ void gok_editor_run()
 	m_bSkipUpdate = TRUE;
 	
 	/* create the parameters dialog */
-	m_pEditorXML = gok_glade_xml_new("gok.glade2", "windowEditor");
-	m_pWindowEditor = glade_xml_get_widget(m_pEditorXML, "windowEditor");
-	g_assert(m_pWindowEditor != NULL);
+	builder = gok_ui_helper_load_file ("gok-editor.ui");
+	g_assert (builder != NULL);
+
+	m_pWindowEditor = WID ("window");
 	gtk_widget_show (m_pWindowEditor);
-	
+
 	/* create the keyboard window */
 	m_pWindowKeyboard = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-	gtk_object_set_data (GTK_OBJECT (m_pWindowKeyboard), "m_pWindowKeyboard", m_pWindowKeyboard);
 	gtk_window_set_title (GTK_WINDOW (m_pWindowKeyboard), _(TITLE_GOK_EDITOR));
 
-	/* create a window group */
-/*	m_pWindowGroup = gtk_window_group_new();	
-	g_assert (m_pWindowGroup!= NULL);
-	gtk_window_group_add_window(m_pWindowGroup, (GtkWindow*)m_pWindowEditor);
-	gtk_window_group_add_window(m_pWindowGroup, (GtkWindow*)m_pWindowKeyboard);
-	*/
-
 	/* handle the 'delete' event so the keyboard window will not close */
-	gtk_signal_connect (GTK_OBJECT (m_pWindowKeyboard), "delete_event",
-                      GTK_SIGNAL_FUNC (on_editor_keyboard_delete_event),
-                      NULL);
+	g_signal_connect (m_pWindowKeyboard, "delete_event",
+			  G_CALLBACK (on_editor_keyboard_delete_event), NULL);
 	
 	/* TODO - do not allow the user to resize the keyboard window */
 
 	/* add the 'fixed' container to the window */
 	fixed1 = gtk_fixed_new ();
-	gtk_widget_ref (fixed1);
-	gtk_object_set_data_full (GTK_OBJECT (m_pWindowKeyboard), "fixed1", fixed1,
-                            (GtkDestroyNotify) gtk_widget_unref);
+	g_object_ref (fixed1);
+	g_object_set_data_full (G_OBJECT (m_pWindowKeyboard), "fixed1", fixed1,
+				(GDestroyNotify) g_object_unref);
 	gtk_widget_show (fixed1);
 	gtk_container_add (GTK_CONTAINER (m_pWindowKeyboard), fixed1);
 	gtk_widget_show (m_pWindowKeyboard);
@@ -132,6 +125,8 @@ void gok_editor_close()
 	{
 		g_free (m_pFilename);
 	}
+
+	g_object_unref (builder);
 }
 
 /**
@@ -147,6 +142,7 @@ void gok_editor_on_exit ()
 	if (m_bFileModified == TRUE)
 	{
 		/* ask if user wants to lose their changes */
+		/*** TODO: code dup ***/
 		pDialog = gtk_message_dialog_new (GTK_WINDOW(m_pWindowEditor),
 					GTK_DIALOG_DESTROY_WITH_PARENT,
 					GTK_MESSAGE_QUESTION,
@@ -180,6 +176,7 @@ void gok_editor_new_file ()
 	if (m_bFileModified == TRUE)
 	{
 		/* ask if user wants to lose their changes */
+		/*** TODO: code dup ***/
 		pDialog = gtk_message_dialog_new (GTK_WINDOW(m_pWindowEditor),
 					GTK_DIALOG_DESTROY_WITH_PARENT,
 					GTK_MESSAGE_QUESTION,
@@ -217,8 +214,6 @@ void gok_editor_new_file ()
 	m_pKeyboard = gok_keyboard_new();
 	gok_keyboard_set_name (m_pKeyboard, _("new"));
 	m_pKeyboard->bSupportsWordCompletion = FALSE;
-	m_pKeyboard->bSupportsCommandPrediction = FALSE;
-	
 
 	gok_editor_add_key();
 	gok_editor_add_key();
@@ -253,13 +248,13 @@ void gok_editor_open_file()
 	GtkWidget* pDialog;
 	gint response;
 	gchar* filename;
-	GtkWidget* pEntry;
 	GokKey* pKey;
 	GtkFileFilter *filter;
 	
 	if (m_bFileModified == TRUE)
 	{
 		/* ask if user wants to lose their changes */
+		/*** TODO: code dup ***/
 		pDialog = gtk_message_dialog_new (GTK_WINDOW(m_pWindowEditor),
 					GTK_DIALOG_DESTROY_WITH_PARENT,
 					GTK_MESSAGE_QUESTION,
@@ -353,9 +348,8 @@ void gok_editor_open_file()
 	
 	/* display info about the keyboard */
 	/* keyboard name */
-	pEntry = glade_xml_get_widget (m_pEditorXML, "entryKeyboardName");
-	g_assert (pEntry != NULL);
-	gtk_entry_set_text (GTK_ENTRY(pEntry), gok_keyboard_get_name(m_pKeyboard));
+	gtk_entry_set_text (GTK_ENTRY (OID ("entryKeyboardName")),
+			    gok_keyboard_get_name (m_pKeyboard));
 	
 	/* TODO - command prediction and word completion flags */
 	
@@ -395,19 +389,16 @@ void gok_editor_touch_file ( gboolean modified )
 */
 void gok_editor_show_parameters (GokKey* pKey)
 {
-	GtkWidget* pEntryLabel;
-	GtkWidget* pSpin;
-	
+	GtkEntry *pEntryLabel;
+
 	gok_log_enter();
 
+	pEntryLabel = GTK_ENTRY (OID ("entryLabel"));
 	/* normal key label */
-	pEntryLabel = glade_xml_get_widget (m_pEditorXML, "entryLabel");
-	g_assert (pEntryLabel != NULL);
-
 	if (pKey == NULL)
 	{
 		/* reset all the entry fields */
-		gtk_entry_set_text (GTK_ENTRY(pEntryLabel), "");
+		gtk_entry_set_text (pEntryLabel, "");
 		
 		return;
 	}
@@ -417,26 +408,17 @@ void gok_editor_show_parameters (GokKey* pKey)
 	g_assert(pKey->Left < pKey->Right);
 	g_assert(pKey->Top  < pKey->Bottom);
 
-	gtk_entry_set_text (GTK_ENTRY(pEntryLabel), gok_key_get_label (pKey));
+	gtk_entry_set_text (pEntryLabel, gok_key_get_label (pKey));
 
 	/* location */
-	pSpin = glade_xml_get_widget (m_pEditorXML, "spinLeft");
-	g_assert (pSpin != NULL);
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON(pSpin), pKey->Left);
-	pSpin = glade_xml_get_widget (m_pEditorXML, "spinRight");
-	g_assert (pSpin != NULL);
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON(pSpin), pKey->Right);
-	pSpin = glade_xml_get_widget (m_pEditorXML, "spinTop");
-	g_assert (pSpin != NULL);
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON(pSpin), pKey->Top);
-	pSpin = glade_xml_get_widget (m_pEditorXML, "spinBottom");
-	g_assert (pSpin != NULL);
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON(pSpin), pKey->Bottom);
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (OID ("spinLeft")), pKey->Left);
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (OID ("spinRight")), pKey->Right);
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (OID ("spinTop")), pKey->Top);
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (OID ("spinBottom")), pKey->Bottom);
 
 	m_bSkipUpdate = FALSE;
 
 	gok_log_leave();
-		
 }
 
 /**
@@ -596,7 +578,6 @@ void gok_editor_duplicate_key ()
 */
 void gok_editor_update_key()
 {
-	GtkWidget* pSpin;
 	gint top;
 	gint bottom;
 	gint left;
@@ -610,21 +591,10 @@ void gok_editor_update_key()
 	if (m_bSkipUpdate == FALSE)
 	{
 		/* location */
-		pSpin = glade_xml_get_widget (m_pEditorXML, "spinLeft");
-		g_assert (pSpin != NULL);
-		left = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(pSpin));
-		
-		pSpin = glade_xml_get_widget (m_pEditorXML, "spinRight");
-		g_assert (pSpin != NULL);
-		right = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(pSpin));
-		
-		pSpin = glade_xml_get_widget (m_pEditorXML, "spinTop");
-		g_assert (pSpin != NULL);
-		top = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(pSpin));
-		
-		pSpin = glade_xml_get_widget (m_pEditorXML, "spinBottom");
-		g_assert (pSpin != NULL);
-		bottom = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(pSpin));
+		left = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (OID ("spinLeft")));
+		right = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON (OID ("spinRight")));
+		top = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON (OID ("spinTop")));
+		bottom = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON (OID ("spinBottom")));
 		
 		if (left >= right)
 		{
@@ -704,7 +674,6 @@ gboolean gok_editor_save_keyboard (GokKeyboard* pKeyboard, gchar* Filename)
 	FILE* pFile;
 	gchar yes[]="yes";
 	gchar no[]="no";
-	gchar* pCommandYesNo;
 	gchar* pCompletionYesNo;
 	GokKey* pKey;
 	GokKeyLabel* pLabel;
@@ -722,10 +691,9 @@ gboolean gok_editor_save_keyboard (GokKeyboard* pKeyboard, gchar* Filename)
 	fputs ("<?xml version=\"1.0\"?>\n", pFile);
 	fputs ("<GOK:GokFile xmlns:GOK=\"http://www.gnome.org/GOK\">\n\n", pFile);
 
-	pCommandYesNo = (pKeyboard->bSupportsCommandPrediction == TRUE) ? yes : no;
 	pCompletionYesNo = (pKeyboard->bSupportsWordCompletion == TRUE) ? yes : no;
-	fprintf (pFile, "<GOK:keyboard name=\"%s\" commandprediction=\"%s\" wordcompletion=\"%s\">\n",
-					pKeyboard->Name, pCommandYesNo, pCompletionYesNo);
+	fprintf (pFile, "<GOK:keyboard name=\"%s\" wordcompletion=\"%s\">\n",
+					pKeyboard->Name, pCompletionYesNo);
 	
 	pKey = pKeyboard->pKeyFirst;
 	while (pKey != NULL)
@@ -1051,7 +1019,7 @@ void gok_editor_message_filename_bad (gchar* Filename)
 
 	buffer = g_strdup_printf (_("This is not a valid keyboard filename:\n%s"),
 				  Filename);
-
+	/*** TODO: code dup ***/
 	pDialog = gtk_message_dialog_new (GTK_WINDOW(m_pWindowEditor),
 				GTK_DIALOG_DESTROY_WITH_PARENT,
 				GTK_MESSAGE_ERROR,
